@@ -4,7 +4,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 use Carp;
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 use Finance::QuoteHist::Generic;
 @ISA = qw(Finance::QuoteHist::Generic);
@@ -69,98 +69,69 @@ sub new {
   my $self = __PACKAGE__->SUPER::new(%parms);
   bless $self, $class;
 
-  $self->set_label_pattern(
-    target_mode => 'dividend',
-    parse_mode  => 'html',
-    label       => 'div',
-    pattern     => qr/(Open|Div)/
-  );
-
   $self;
 }
 
 # override these for other Yahoo sites
 sub url_base_csv    { 'http://ichart.finance.yahoo.com/table.csv' }
 sub url_base_html   { 'http://finance.yahoo.com/q/hp' }
-sub url_base_splits { 'http://finance.yahoo.com/q/bc' }
 
 sub granularities { qw( daily weekly monthly ) }
 
 # Yahoo can fetch dividends and splits. They can be extracted from
 # regular quote results or queried directly.
 
-# Newer full-custom direct query for yahoo splits
-sub splits {
-  my $self = shift;
-  my @symbols = @_ ? @_ : $self->symbols;
-  my $target_mode = 'split';
-  # cache check
-  my @not_seen;
-  foreach my $symbol (@symbols) {
-    my @r = $self->result_rows($target_mode, $symbol);
-    push(@not_seen, $symbol) unless @r;
-  }
-  # example URL: http://finance.yahoo.com/q/bc?s=IBM&t=my
-  foreach my $symbol (@not_seen) {
-    my $url = $self->url_base_splits() . "?s=$symbol&t=my";
-    print STDERR "Processing ($symbol:$target_mode) $url\n" if $self->{verbose};
-    my $data = $self->{url_cache}{$url} || $self->fetch($url);
-    $self->{url_cache}{$url} = $data;
-    print STDERR "Custom parse for ($symbol:$target_mode)\n" if $self->{verbose};
-    my $te = HTML::TableExtract->new(headers => ['Splits:']);
-    $te->parse($data);
-    my $table = $te->first_table_found;
-    if ($table) {
-      my($split_line) = grep(defined && /split/i, $table->hrow);
-      $split_line =~ s/^\s*splits:?\s*//i;
-      my @rows;
-      foreach (grep(/\w+/, split(/\]\s*,\s+/, $split_line))) {
-        s/\s+$//;
-        next if /none/i;
-        next unless s/\s*\[(\d+):(\d+).*$//;
-        my($post, $pre) = ($1, $2);
-        my $date = ParseDate($_)
-          or croak "Problem parsing date string '$_'\n";
-        push(@rows, [$date, $post, $pre]);
-      }
-      @rows = $self->rows(\@rows);
-      $self->_store_results($target_mode, $symbol, 0, \@rows);
-      $self->_target_source($target_mode, $symbol, ref $self);
-    }
-  }
-  my @rows = $self->result_rows($target_mode, @symbols);
-  wantarray ? @rows : \@rows;
-}
-
-# Not so direct splits query
-sub splits_alternate {
-  # An HTML quote query is the only way to go for splits on yahoo, so
-  # we have to signal to ourselves what the source mode should be so
-  # that the _urls() method will generate the proper URL...otherwise
-  # we would get CSV, which has no split info.
-  my $self = shift;
-  $self->save_query;
-  $self->parse_mode('html');
-  $self->start_date(undef, 0);
-  $self->end_date('today', 0);
-  $self->{quiet} = 1;
-  $self->target_mode('dividend');
-  my $rows = $self->dividends(@_);
-  if (!@$rows) {
-    $self->target_mode('quote');
-    $self->granularity('monthly');
-    $rows = $self->quotes(@_);
-  }
-  $self->restore_query;
-  $self->result_rows('split');
-}
+#sub html_parser {
+#  my($self, %parms) = @_;
+#  my $target_mode = $parms{target_mode} || $self->target_mode;
+#  return $self->SUPER::html_parser(%parms) unless $target_mode eq 'split';
+#  sub {
+#    my $data = shift;
+#    my $html_string;
+#    if (ref $data) {
+#      local($/);
+#      $html_string = <$data>;
+#    }
+#    else {
+#      $html_string = $data;
+#    }
+#    my %te_parms = (
+#      headers => ['Splits:'],
+#      debug   => $self->{debug},
+#    );
+#    my $te = HTML::TableExtract->new(%te_parms);
+#    $te->parse($html_string);
+#    my $table = $te->first_table_found || return [];
+#    my($split_line) = grep(defined && /split/i, $table->hrow);
+#    $split_line =~ s/^\s*splits:?\s*//i;
+#    my @rows;
+#    foreach (grep(/\w+/, split(/\]\s*,\s+/, $split_line))) {
+#      s/\s+$//;
+#      next if /none/i;
+#      next unless s/\s*\[(\d+):(\d+).*$//;
+#      my($post, $pre) = ($1, $2);
+#      my $date = ParseDate($_)
+#        or croak "Problem parsing date string '$_'\n";
+#      push(@rows, [$date, $post, $pre]);
+#    }
+#    \@rows;
+#  };
+#}
 
 sub labels {
   my $self = shift;
   my %parms = @_;
-  my $target_mode = $self->target_mode;
-  my @labels = $self->SUPER::labels(%parms);
-  push(@labels, 'adj') if $target_mode eq 'quote';
+  my $target_mode = $parms{target_mode} || $self->target_mode;
+  my $parse_mode  = $parms{parse_mode}  || $self->parse_mode;
+  my @labels;
+  if ($target_mode eq 'split') {
+    @labels = qw( date open );
+    $self->parse_mode('html');
+  }
+  else {
+    @labels = $self->SUPER::labels(%parms);
+    push(@labels, 'adj') if $target_mode eq 'quote';
+  }
   @labels;
 }
 
@@ -171,12 +142,14 @@ sub extractors {
   my %parms = @_;
   my $target_mode = $parms{target_mode} || $self->target_mode;
   my $parse_mode  = $parms{parse_mode}  || $self->parse_mode;
+  if ($target_mode eq 'split') {
+    $parse_mode = 'html';
+    $self->parse_mode($parse_mode);
+  }
   return () if $parse_mode eq 'csv';
-  return () unless $target_mode eq 'quote' || $target_mode eq 'dividend';
+  my %extractors;
   my $date_column = $self->label_column('date');
   my $split_column = 1;
-  my %extractors;
-  # for both quote and dividend results in html mode
   $extractors{'split'} = sub {
     my $row = shift;
     die "row as array ref required" unless ref $row;
@@ -185,19 +158,17 @@ sub extractors {
     return undef unless $post && $pre;
     [ $row->[$date_column], $post, $pre ];
   };
-  if ($target_mode eq 'quote') {
-    my $div_column = 1;
-    $extractors{dividend} = sub {
-      # Get a row as array ref, see if it contains dividend info. If so,
-      # return another array ref with the extracted info.
-      my $row = shift;
-      die "row as array ref required\n" unless ref $row;
-      # example dividend: "$0.01 Cash Dividend"
-      my($div) = $row->[$div_column] =~ /\$*(\d*\.\d+).*Dividend/i;
-      return undef unless defined $div;
-      [ $row->[$date_column], $row->[$div_column] ];
-    };
-  }
+  #my $div_column = 1;
+  #$extractors{dividend} = sub {
+  #  # Get a row as array ref, see if it contains dividend info. If so,
+  #  # return another array ref with the extracted info.
+  #  my $row = shift;
+  #  die "row as array ref required\n" unless ref $row;
+  #  # example dividend: "$0.01 Cash Dividend"
+  #  my($div) = $row->[$div_column] =~ /\$*(\d*\.\d+).*Dividend/i;
+  #  return undef unless defined $div;
+  #  [ $row->[$date_column], $row->[$div_column] ];
+  #};
   %extractors;
 }
 
@@ -225,6 +196,11 @@ sub url_maker {
     ($start_date, $end_date) = ($end_date, $start_date);
   }
 
+  if ($target_mode eq 'split') {
+    $self->parse_mode('html');
+    $parse_mode = 'html';
+  }
+
   my $base_url = $parse_mode eq 'csv' ? $self->url_base_csv() :
                                         $self->url_base_html();
   my @base_parms;
@@ -242,14 +218,13 @@ sub url_maker {
   $ticker ||= 'BOOLEAN';
   push(@base_parms, "g=$g", "s=$ticker");
   
-  if ($parse_mode eq 'html' && $target_mode eq 'quote' || $target_mode eq 'dividend') {
+  if ($parse_mode eq 'html') {
     my $cursor = 0;
     my $window = 66;
     return sub {
       my $url = $base_url . '?' .
         join('&', @base_parms,
                  "z=$window", "y=$cursor");
-      $url .= '&ignore=.csv' if $parse_mode eq 'csv';
       $cursor += $window;
       $url;
     }
@@ -400,7 +375,7 @@ Matthew P. Sisk, E<lt>F<sisk@mojotoad.com>E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2010 Matthew P. Sisk. All rights reserved. All wrongs
+Copyright (c) 2000-2014 Matthew P. Sisk. All rights reserved. All wrongs
 revenged. This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
 
